pub trait ClosureFnMutT2Ext<T2> {
// Required method
fn from_func_no_args<F>(func: F) -> Self
where dyn FnMut() -> T2: WasmClosure,
F: IntoWasmClosure<dyn FnMut() -> T2> + 'static;
}Required Methods
Sourcefn from_func_no_args<F>(func: F) -> Self
fn from_func_no_args<F>(func: F) -> Self
Equivelant of new but without need for explicit type annotations
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<T2> ClosureFnMutT2Ext<T2> for Closure<dyn FnMut() -> T2>
impl<T2> ClosureFnMutT2Ext<T2> for Closure<dyn FnMut() -> T2>
Sourcefn from_func_no_args<F>(func: F) -> Self
fn from_func_no_args<F>(func: F) -> Self
Equivelant of new but without need for explicit type annotations